Returns the alpha decay parameter vector, which plays the role of "coefficients" in the IDW model.
Usage
# S3 method for class 'interpElections_result'
coef(object, ...)Returns the alpha decay parameter vector, which plays the role of "coefficients" in the IDW model.
# S3 method for class 'interpElections_result'
coef(object, ...)